tuples.html

#### Tuples

A tuple is a simple comma-separated list of elements inside parenthesis. For example,
(a, b, c)
...is a tuple of 3 elements--a, b, and c.
Tuples are fast and easy to use. With variadic macro support it is not necessary to know the size of a tuple; without variadic macro support all access to tuples requires knowledge of its size. Use a tuple instead of an array if your compiler supports variadic macros, since a tuple has all of the functionality as an array and is easier syntactically to use.
Elements of a tuple can be extracted with BOOST_PP_TUPLE_ELEM.

#### Primitives

- BOOST_PP_TUPLE_ELEM

© Copyright Housemarque Oy 2002
© Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)